@@ -330,8 +330,11 @@ class fMMS_GUI(hildon.Program):
 			for fname in filelist:
 				mtime = time.strftime("%Y-%m-%d | %H:%M", time.localtime(os.path.getmtime(self._pushdir + fname)))
 				varlist = self._read_push_as_list(self._pushdir + fname)
-				sender = varlist['From']
-				sender = sender.replace("/TYPE=PLMN", "")
+				try:
+					sender = varlist['From']
+					sender = sender.replace("/TYPE=PLMN", "")
+				except:
+					sender = "0000000"
 				
 				sendername = self.ch.get_name_from_number(sender)
 				photo = icon_theme.load_icon("general_default_avatar", 48, 0)
@@ -695,7 +698,10 @@ class fMMS_GUI(hildon.Program):
 	def _get_mms_from_push(self, fname):
 		plist = self._read_push_as_list(fname)
 
-		sndr = plist['From']
+		try:
+			sndr = plist['From']
+		except:
+			sndr = "0000000"
 		url = plist['Content-Location']
 		print url
 		trans_id = plist['Transaction-Id']
