@@ -77,16 +77,33 @@ class PushHandler:
 		#print data
 		wspdata = decoder.decodeCustom(data)
 		# extract some data we want to use
+		
+		sndr, url, trans_id = None, None, None
+		bus = dbus.SystemBus()
 		try:
 			url = wspdata["Content-Location"]
 			print "content-location:", url
-			trans_id = wspdata["Transaction-Id"]
-			trans_id = str(trans_id)
-			print "transid:", trans_id
+		except Exception, e:
+			print "no content-location in push; aborting...", e, e.args
+			proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+			interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+			interface.SystemNoteInfoprint ("fMMS: Failed to parse SMS PUSH.")
+		try:
 			sndr = wspdata["From"]
 			print "Sender:", sndr
 		except Exception, e:
 			print "exception on values from decode:", e, e.args
+			
+		try:
+			trans_id = wspdata["Transaction-Id"]
+			trans_id = str(trans_id)
+			print "transid:", trans_id
+		except Exception, e:
+			print "no transid in sms push; aborting...", e, e.args
+			proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+			interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+			interface.SystemNoteInfoprint ("fMMS: Failed to parse SMS PUSH.")
+			raise
 		
 		if sndr == None:
 			print "No sender... Setting to unknown"
@@ -161,8 +178,12 @@ class PushHandler:
 			con.connect()
 			
 			### send the m-notifyresp-ind first
-			notifyresp = self._send_notify_resp(transaction)
-			print "notifyresp sent"
+			try:
+				notifyresp = self._send_notify_resp(transaction)
+				print "notifyresp sent"
+			except:
+				print "notify sending failed..."
+			
 			# this seems to work like it should
 			# TODO: dont hardcode timeout
 			# god it would be nice with python2.6 for timeout= in urllib2
@@ -188,12 +209,15 @@ class PushHandler:
 				print "fetched ", location, " and wrote to file", fp
 				
 			# send acknowledge we got it ok
-			ack = self._send_acknowledge(transaction)
-			print "ack sent"
+			try:
+				ack = self._send_acknowledge(transaction)
+				print "ack sent"
+			except:
+				print "sending ack failed"
+			
 			con.disconnect()
 			
 		except Exception, e:
-			print "fetch failed."
 			print e, e.args
 			print "removing dir..."
 			os.rmdir(dirname)
@@ -224,7 +248,9 @@ class PushHandler:
 		mms.headers['Transaction-Id'] = transid
 		mms.headers['MMS-Version'] = "1.3"
 		
+		print "setting up ack sender"
 		ack = MMSSender(customMMS=True)
+		print "sending ack..."
 		out = ack.sendMMS(mms)
 		print "m-acknowledge-ind:", out
 		return out
